/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

/**
 * \file
 * Various file descriptors utilities
 *
 * Essentially, this provides wrappers for setting the close-and-exec flag
 * in a race-free manner whenever the kernel and C library support it
 * (for instance using POSIX.1-2008.'s O_CLOEXEC for open(2)), and falling
 * back to fcntl(2) otherwise.
 */

#ifndef _FDUTILS_H
#define _FDUTILS_H

/**
 * Open a file/directory with the close-on-exec flag set
 *
 * See open(2) for parameters
 */
int open_cloexec(const char *pathname, int flags);

/**
 * Open a file/directory with the close-on-exec flag set
 *
 * See openat(2) for parameters
 */
int openat_cloexec(int dirfd, const char *pathname, int flags);

/**
 * Open a file with the close-on-exec flag set
 *
 * See fopen(3) for parameters
 */
FILE *fopen_cloexec(const char *path, const char *mode);

/**
 * Create a pipe with the close-on-exec flag set
 *
 * See pipe(2) for parameters
 */
int pipe_cloexec(int pipefd[2]);

#endif /* _FDUTILS_H */
