/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

#if HAVE_CONFIG_H
# include "config.h"
#endif

#include <stdio.h>
#include <unistd.h>
#include <string.h>

#include "../cmdgen.h"


/* --------------------------------------------------------------------------
 *   private functions
 */

static void
usage(const char *argv0)
{
	fprintf(stderr,
	  "\n"
	  "Usage: %s [ <test file> ]\n"
	  "\n"
	  "This programs takes a test file as input and generates a runnable\n"
	  "test script from it, whose output is meant to be merged back into\n"
	  "a test script later on. The comparison between the original test\n"
	  "and the merged one will determine whether the test passed or\n"
	  "failed.\n"
	  "\n"
	  "If test filename is unspecified or is '-', reading test from\n"
	  "standard input.\n"
	  "", argv0);
}



/* --------------------------------------------------------------------------
 *   public functions
 */

int
main(int argc, char **argv)
{
	FILE *in, *out = stdout;

	if (argc > 2) {
		usage(argv[0]);
		return 1;
	}

	if (argc == 2) {
		if (!strcmp(argv[1], "-")) {
			in = stdin;
		} else {
			in = fopen(argv[1], "r");
			if (!in) {
				perror("fopen");
				return 1;
			}
		}
	} else if (isatty(STDIN_FILENO)) {
		usage(argv[0]);
		fprintf(stderr, "\nerror: no test input provided\n");
		return 1;
	} else {
		in = stdin;
	}

	if (cmdgen_process_stream(in, out) == -1)
		return 1;

	return 0;
}
