/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

#if HAVE_CONFIG_H
# include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <errno.h>

#include "../merge.h"



/* --------------------------------------------------------------------------
 *   private functions
 */

static void
__attribute__((noreturn))
usage(const char *argv0, const char *err)
{
	int rc = (err && *err) ? 1 : 0;

	fprintf(stderr,
	  "\n"
	  "Usage: %s [ <options> ] <test file> [ <test result file> ]\n"
	  "\n"
	  "This programs merges the results of a script test back into a\n"
	  "test file, which can then be compared with the original test.\n"
	  "\n"
	  "If no result file is specified, reading it from standard input.\n"
	  "\n"
	  "Options:\n"
	  " -h       show this help text\n"
	  " -V       verbatim mode, disable escaping and regexp/glob support\n"
	  "", argv0);

	if (rc != 0)
		fprintf(stderr, "\nError: %s\n", err);

	exit(rc);
}



/* --------------------------------------------------------------------------
 *   public functions
 */

int
main(int argc, char **argv)
{
	FILE *fp_res = NULL, *fp_merge = stdout, *fp_test;
	unsigned int flags = 0;
	int res, opt, nargs;

	while ((opt = getopt(argc, argv, "hV")) != -1)
		switch (opt) {
		case 'h': usage(argv[0], "");
		case 'V': flags |= MERGE_FLAG_VERBATIM; break;
		default: usage(argv[0], "Invalid option");
		}

	nargs = argc - optind;
	switch (nargs) {
	case 2:
		fp_res = fopen(argv[optind + 1], "r");
		if (!fp_res) {
			fprintf(stderr, "fopen: %s: %s\n", strerror(errno),
			                                   argv[optind + 1]);
			return 1;
		}
		/* fall through */
	case 1:
		fp_test = fopen(argv[optind], "r");
		if (!fp_test) {
			fprintf(stderr, "fopen: %s: %s\n", strerror(errno),
			                                   argv[optind]);
			return 1;
		}
		break;
	default:
		usage(argv[0], "");
	}

	if (!fp_res) {
		if (isatty(STDIN_FILENO))
			usage(argv[0], "No test results provided");
		else
			fp_res = stdin;
	}

	res = merge_process_streams(fp_test, fp_res, fp_merge, flags);

	fclose(fp_test);
	if (fp_res != stdin)
		fclose(fp_res);

	return !!res;
}
