/*
 * Copyright 2011 Cedric Duval <cedricduval@free.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2.
 *
 * See the accompanying COPYING file for more details.
 */

/**
 * \file
 * Simple write buffer for concatenating strings before printing them out
 */

#ifndef _WBUF_H
#define _WBUF_H

/**
 * Initialize a buffer
 *
 * \param[in] out  Output buffer to print to
 *
 * \return         Buffer handle or NULL if it couldn't be allocated
 */
struct wbuf *wbuf_init(FILE *out);

/**
 * Release a buffer
 *
 * \param[in] w  Buffer's handle
 */
void wbuf_free(struct wbuf *w);

/**
 * Append text to a buffer
 *
 * \param[in] w     Buffer's handle
 * \param[in] text  Text to append
 *
 * \return          0 if the text could be appended, -1 otherwise
 */
int wbuf_append(struct wbuf *w, const char *text);

/**
 * Print out and flush the current buffer's content
 *
 * \param[in] w  Buffer's handle
 *
 * \return       -1 if the text could be printed out, -1 otherwise
 */
int wbuf_print(struct wbuf *w);

#endif /* _WBUF_H */
